@@ -16,7 +16,7 @@ import pandas as pd
 
 __author__ = "Jordan Wildon (@jordanwildon)"
 __license__ = "MIT License"
-__version__ = "1.1.12"
+__version__ = "1.1.13"
 __maintainer__ = "Jordan Wildon"
 __email__ = "j.wildon@pm.me"
 __status__ = "Development"
@@ -201,7 +201,7 @@ def cli(verbose,name,archive,media,forwards,participants,user,info,location):
         file = f_directory + alphanumeric + '_edgelist.csv'
         for n in name:
             async def main():
-                click.echo('Listing forwards from {n}'.format(n))
+                click.echo('Listing forwards from {0}'.format(n))
                 forwards_list = []
                 to_ent = await client.get_entity(n)
                 to_title = to_ent.title
@@ -384,6 +384,7 @@ def cli(verbose,name,archive,media,forwards,participants,user,info,location):
             client.loop.run_until_complete(main())
 
     if location:
+        client.connect()
         click.echo('Searching for users near: {0}'.format(location))
         latitude, longitude = location.split(sep=',')
 
